@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2010 Oracle
+ * Copyright (c) 2010, 2023 Oracle and others
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
@@ -950,7 +950,9 @@ public final class FacetedProjectFrameworkImpl
                 }
                 else if( action.getType() == Action.Type.INSTALL && existing != null )
                 {
-                    ptype = ValidationProblem.Type.FACET_ALREADY_INSTALLED;
+                    // XXX this information is nearly useless to the end user
+//					FacetCorePlugin.log(new UnsupportedOperationException("Attempting to install a second facet version for an already installed facet: " + action.getProjectFacetVersion() + "[" + existing + "]")); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
+//                    ptype = ValidationProblem.Type.FACET_ALREADY_INSTALLED;
                 }
             }
             
