@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2001, 2018 IBM Corporation and others.
+ * Copyright (c) 2001, 2020 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
  * which accompanies this distribution, and is available at
@@ -83,6 +83,19 @@ class WorkspaceTaskScanner {
 		fCurrentIgnoreContentTypes = new IContentType[0];
 	}
 
+	private IFileTaskScanner[] combined(IFileTaskScanner[] a, IFileTaskScanner[] b) {
+		if (a.length == 0) {
+			return b;
+		}
+		if (b.length == 0) {
+			return a;
+		}
+		IFileTaskScanner[] both = new  IFileTaskScanner[a.length + b.length];
+		System.arraycopy(a, 0, both, 0, a.length);
+		System.arraycopy(b, 0, both, a.length, b.length);
+		return both;
+	}
+
 	private IContentType[] detectContentTypes(IResource resource) {
 		IContentType[] types = null;
 		if (resource.getType() == IResource.FILE && resource.isAccessible()) {
@@ -289,13 +302,13 @@ class WorkspaceTaskScanner {
 							for (int i = 0; i < markerAttributeMaps.length; i++) {
 								String specifiedMarkerType = (String) markerAttributeMaps[i].get(IMarker.TASK);
 								IMarker marker = finalFile.createMarker(specifiedMarkerType);
-								marker.setAttributes(markerAttributeMaps[i]);
-								marker.setAttribute(IMarker.USER_EDITABLE, Boolean.FALSE);
-								marker.setAttribute(MODIFICATION_STAMP, Long.toString(file.getModificationStamp()));
+								markerAttributeMaps[i].put(IMarker.USER_EDITABLE, Boolean.FALSE);
+								markerAttributeMaps[i].put(MODIFICATION_STAMP, Long.toString(file.getModificationStamp()));
 								if (IMarker.TASK.equals(specifiedMarkerType)) {
 									// set to synthetic and make user editable
-									marker.setAttribute(SYNTHETIC_TASK, true);
+									markerAttributeMaps[i].put(SYNTHETIC_TASK, true);
 								}
+								marker.setAttributes(markerAttributeMaps[i]);
 							}
 						}
 						progressMonitor.worked(1);
@@ -303,7 +316,7 @@ class WorkspaceTaskScanner {
 					}
 				};
 				if (file.isAccessible()) {
-					finalFile.getWorkspace().run(r, ResourcesPlugin.getWorkspace().getRuleFactory().modifyRule(file), IWorkspace.AVOID_UPDATE, monitor);
+					finalFile.getWorkspace().run(r, ResourcesPlugin.getWorkspace().getRuleFactory().markerRule(file), IWorkspace.AVOID_UPDATE, monitor);
 				}
 			}
 			catch (CoreException e1) {
@@ -395,10 +408,16 @@ class WorkspaceTaskScanner {
 				}
 				fileScanners = registry.getFileTaskScanners(validTypes.toArray(new IContentType[validTypes.size()]));
 			}
+			FileTaskScannerRegistryReader.EnabledDisabledScanners filenameExtensionScanners = registry.getFileTaskScanners(file.getFullPath(), fCurrentIgnoreContentTypes);
+			fileScanners = combined(fileScanners, filenameExtensionScanners.enabled);
 			monitor.worked(1);
 			if (ignoredFileScanners != null && ignoredFileScanners.length > 0) {
-				for (int i = 0; i < ignoredFileScanners.length; i++)
+				for (int i = 0; i < ignoredFileScanners.length; i++) {
 					markerTypes.add(ignoredFileScanners[i].getMarkerType());
+				}
+			}
+			for (int i = 0; i < filenameExtensionScanners.disabled.length; i++) {
+				markerTypes.add(filenameExtensionScanners.disabled[i].getMarkerType());
 			}
 
 			if (fileScanners.length > 0) {
@@ -441,7 +460,8 @@ class WorkspaceTaskScanner {
 			return;
 		// only update markers if we ran a scanner on this file
 		if (fileScanners != null && fileScanners.length > 0 ||
-				ignoredFileScanners != null && ignoredFileScanners.length > 0) {
+				ignoredFileScanners != null && ignoredFileScanners.length > 0 ||
+				markerTypes.size() > 0) {
 			IProgressMonitor markerUpdateMonitor = new SubProgressMonitor(monitor, 3, SubProgressMonitor.PREPEND_MAIN_LABEL_TO_SUBTASK);
 			if (markerAttributes != null) {
 				replaceTaskMarkers(file, markerTypes.toArray(new String[markerTypes.size()]), markerAttributes.toArray(new Map[markerAttributes.size()]), markerUpdateMonitor);
