@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2001, 2018 IBM Corporation and others.
+ * Copyright (c) 2001, 2024 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
  * which accompanies this distribution, and is available at
@@ -16,8 +16,6 @@ package org.eclipse.wst.sse.core.internal;
 
 import java.io.ByteArrayInputStream;
 import java.io.File;
-import java.io.FileInputStream;
-import java.io.FileNotFoundException;
 import java.io.IOException;
 import java.io.InputStream;
 import java.net.MalformedURLException;
@@ -583,7 +581,8 @@ public class FileBufferModelManager {
 					catch (CoreException e) {
 						/*
 						 * Should not be possible given the accessible and
-						 * file type check above
+						 * file type check above; maybe a temporary file or
+						 * system that's only advisory locking?
 						 */
 					}
 					if (type == null) {
@@ -592,28 +591,25 @@ public class FileBufferModelManager {
 				}
 			}
 			else {
-				File file = FileBuffers.getSystemFileAtLocation(location);
-				if (file != null) {
-					InputStream input = null;
-					try {
-						input = new FileInputStream(file);
-						type = Platform.getContentTypeManager().findContentTypeFor(input, file.getName());
-					}
-					catch (FileNotFoundException e) {
+				IFileStore fileStore = FileBuffers.getFileStoreAtLocation(location);
+				if (fileStore != null) {
+					try (InputStream input = fileStore.openInputStream(EFS.NONE, null)) {
+						type = Platform.getContentTypeManager().findContentTypeFor(input, fileStore.getName());
 					}
 					catch (IOException e) {
+						/*
+						 * Failure. Resort to finding the content type based
+						 * solely on the file name.
+						 */
 					}
-					finally {
-						if (input != null) {
-							try {
-								input.close();
-							}
-							catch (IOException e1) {
-							}
-						}
+					catch (CoreException e) {
+						/*
+						 * Also failure. Resort to finding the content type based
+						 * solely on the file name.
+						 */
 					}
 					if (type == null) {
-						type = Platform.getContentTypeManager().findContentTypeFor(file.getName());
+						type = Platform.getContentTypeManager().findContentTypeFor(fileStore.getName());
 					}
 				}
 			}
@@ -621,12 +617,8 @@ public class FileBufferModelManager {
 		else {
 			IFileStore fileStore = buffer.getFileStore();
 			if (fileStore != null) {
-				InputStream input = null;
-				try {
-					input = fileStore.openInputStream(EFS.NONE, null);
-					if (input != null) {
-						type = Platform.getContentTypeManager().findContentTypeFor(input, fileStore.getName());
-					}
+				try (InputStream input = fileStore.openInputStream(EFS.NONE, null)) {
+					type = Platform.getContentTypeManager().findContentTypeFor(input, fileStore.getName());
 				}
 				catch (CoreException e) {
 					// failure, assume plain text
@@ -634,15 +626,6 @@ public class FileBufferModelManager {
 				catch (IOException e) {
 					// failure, assume plain text
 				}
-				finally {
-					if (input != null) {
-						try {
-							input.close();
-						}
-						catch (IOException e1) {
-						}
-					}
-				}
 				if (type == null) {
 					type = Platform.getContentTypeManager().findContentTypeFor(fileStore.getName());
 				}
@@ -726,8 +709,10 @@ public class FileBufferModelManager {
 				DocumentInfo info = (DocumentInfo) fDocumentMap.get(buffer.getDocument());
 				if (info != null) {
 					/*
-					 * Note: "info" being null at this point is a slight
-					 * error.
+					 * Note: "info" being null means someone requested a
+					 * model for a file with a text file buffer containing
+					 * a document implementation other than
+					 * StructuredDocument.
 					 * 
 					 * The connect call from above (or at some time earlier in
 					 * the session) would have notified the FileBufferMapper
@@ -748,6 +733,14 @@ public class FileBufferModelManager {
 					model = getModel((IStructuredDocument) bufferDocument);
 				}
 				else {
+					IContentType[] contentTypes = Platform.getContentTypeManager().findContentTypesFor(buffer.getLocation().lastSegment());
+					for (int i = 0; i < contentTypes.length; i++) {
+						IModelHandler handler = ModelHandlerRegistry.getInstance().getHandlerForContentTypeId(contentTypes[i].getId());
+						if (handler != null) {
+							Logger.log(Logger.WARNING, "Detected content type did not match one for which a model handler is registered: " + detectContentType(buffer) + " vs. " + handler.getAssociatedContentTypeId() , null);
+							break;
+						}
+					}
 					/*
 					 * 190768 - Quick diff marks do not disappear in the
 					 * vertical ruler of JavaScript editor and
@@ -791,8 +784,10 @@ public class FileBufferModelManager {
 					DocumentInfo info = (DocumentInfo) fDocumentMap.get(buffer.getDocument());
 					if (info != null) {
 						/*
-						 * Note: "info" being null at this point is a slight
-						 * error.
+						 * Note: "info" being null means someone requested a
+						 * model for a file with a text file buffer containing
+						 * a document implementation other than
+						 * StructuredDocument.
 						 * 
 						 * The connect call from above (or at some time
 						 * earlier in the session) would have notified the
@@ -813,6 +808,14 @@ public class FileBufferModelManager {
 						model = getModel((IStructuredDocument) bufferDocument);
 					}
 					else {
+						IContentType[] contentTypes = Platform.getContentTypeManager().findContentTypesFor(buffer.getLocation().lastSegment());
+						for (int i = 0; i < contentTypes.length; i++) {
+							IModelHandler handler = ModelHandlerRegistry.getInstance().getHandlerForContentTypeId(contentTypes[i].getId());
+							if (handler != null) {
+								Logger.log(Logger.WARNING, "Detected content type did not match one for which a model handler is registered: " + detectContentType(buffer) + " vs. " + handler.getAssociatedContentTypeId() , null);
+								break;
+							}
+						}
 						/*
 						 * 190768 - Quick diff marks do not disappear in the
 						 * vertical ruler of JavaScript editor and
