@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2001, 2005 IBM Corporation and others.
+ * Copyright (c) 2001, 2021 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
  * which accompanies this distribution, and is available at
@@ -24,7 +24,7 @@ public interface JSPCapableParser extends RegionParser, BlockTagParser {
 	 * 
 	 * @return
 	 */
-	List getNestablePrefixes();
+	List<TagMarker> getNestablePrefixes();
 
 	void removeNestablePrefix(String tagName);
 }
