@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2001, 2005 IBM Corporation and others.
+ * Copyright (c) 2001, 2023 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
  * which accompanies this distribution, and is available at
@@ -17,6 +17,10 @@ package org.eclipse.wst.sse.core.internal.undo;
 import org.eclipse.emf.common.command.Command;
 import org.eclipse.emf.common.command.CommandStack;
 
+/**
+ * @deprecated - expect its removal in bundle version 1.3 or 2024-06, whichever comes later
+ */
+@Deprecated
 public interface IStructuredTextUndoManager {
 
 	/**
