@@ -1,9 +1,11 @@
 /*******************************************************************************
- * Copyright (c) 2001, 2010 IBM Corporation and others.
+ * Copyright (c) 2001, 2019 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * are made available under the terms of the Eclipse Public License 2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
@@ -13,11 +15,8 @@
  *******************************************************************************/
 package org.eclipse.wst.sse.core.utils;
 
-
-
 import java.util.ArrayList;
 import java.util.List;
-import com.ibm.icu.util.StringTokenizer;
 
 import org.eclipse.jface.text.BadLocationException;
 import org.eclipse.jface.text.Document;
@@ -25,6 +24,8 @@ import org.eclipse.jface.text.IDocument;
 import org.eclipse.jface.text.IRegion;
 import org.eclipse.wst.sse.core.internal.Logger;
 
+import com.ibm.icu.util.StringTokenizer;
+
 
 public class StringUtils {
 	protected static final String AMPERSTAND = "&"; //$NON-NLS-1$
@@ -83,7 +84,7 @@ public class StringUtils {
 	 * @return the list of words
 	 */
 	public static String[] asArray(String value) {
-		ArrayList list = new ArrayList();
+		List<String> list = new ArrayList<>();
 		StringTokenizer stok = new StringTokenizer(value);
 		while (stok.hasMoreTokens()) {
 			list.add(stok.nextToken());
@@ -116,7 +117,7 @@ public class StringUtils {
 	 * @return the list of words
 	 */
 	public static String[] asArray(String value, String delim, boolean returnTokens) {
-		ArrayList list = new ArrayList();
+		List<String> list = new ArrayList<>();
 		StringTokenizer stok = new StringTokenizer(value, delim, returnTokens);
 		while (stok.hasMoreTokens()) {
 			list.add(stok.nextToken());
@@ -222,7 +223,7 @@ public class StringUtils {
 
 		String newText = ""; //$NON-NLS-1$
 		int lineCount = tempDoc.getNumberOfLines();
-		StringBuffer sb = new StringBuffer(newText);
+		StringBuilder sb = new StringBuilder(newText);
 		for (int i = 0; i < lineCount; i++) {
 			try {
 				org.eclipse.jface.text.IRegion lineInfo = tempDoc.getLineInformation(i);
@@ -281,7 +282,7 @@ public class StringUtils {
 	public static String escape(String normalString) {
 		if (normalString == null)
 			return null;
-		StringBuffer escapedBuffer = new StringBuffer();
+		StringBuilder escapedBuffer = new StringBuilder();
 		StringTokenizer toker = new StringTokenizer(normalString, EQUAL_SIGN + LINE_FEED + CARRIAGE_RETURN + LINE_TAB, true);
 		String chunk = null;
 		while (toker.hasMoreTokens()) {
@@ -307,7 +308,7 @@ public class StringUtils {
 
 	/**
 	 * Returns the first line of the given text without a trailing delimiter
-	 * 
+	 *
 	 * @param text
 	 * @return
 	 */
@@ -327,6 +328,48 @@ public class StringUtils {
 		return text;
 	}
 
+	/**
+	 * Returns the first line of the given text, up to a certain length, appending ellipses as indicated
+	 *
+	 * @return
+	 */
+	public static final String firstLine(String s, int limit, boolean appendEllipsesIfExceeded) {
+		int lineSeparatorIndex = 0;
+		int fullLength = s.length();
+		int startOffset = -1;
+		do {
+			startOffset++;
+		}
+		while (startOffset < fullLength && Character.isWhitespace(s.charAt(startOffset)));
+
+		if (startOffset == fullLength) {
+			return ""; //$NON-NLS-1$
+		}
+
+		// find the first line delimiter
+		if ((lineSeparatorIndex = s.indexOf('\r', startOffset)) < 0) {
+			lineSeparatorIndex = s.indexOf('\n', startOffset);
+		}
+
+		if (lineSeparatorIndex > 0) {
+			if (appendEllipsesIfExceeded) {
+				return s.substring(startOffset, Math.min(startOffset + limit, lineSeparatorIndex)).concat("...");
+			}
+			else {
+				return s.substring(startOffset, Math.min(startOffset + limit, lineSeparatorIndex));
+			}
+		}
+		else if (fullLength - startOffset > limit) {
+			if (appendEllipsesIfExceeded) {
+				return s.substring(startOffset, startOffset + limit).concat("...");
+			}
+			else {
+				return s.substring(startOffset, startOffset + limit);
+			}
+		}
+		return s;
+	}
+
 	public static int indexOfLastLineDelimiter(String aString) {
 		return indexOfLastLineDelimiter(aString, aString.length());
 	}
@@ -505,7 +548,7 @@ public class StringUtils {
 	 * @todo Generated comment
 	 */
 	public static String pack(String[] strings) {
-		StringBuffer buf = new StringBuffer();
+		StringBuilder buf = new StringBuilder();
 		for (int i = 0; i < strings.length; i++) {
 			buf.append(StringUtils.replace(strings[i], ",", "&comma;")); //$NON-NLS-1$ //$NON-NLS-2$
 			if (i < strings.length - 1)
@@ -520,7 +563,7 @@ public class StringUtils {
 	 */
 	public static String paste(String oldText, String newText, int start, int length) {
 		String result = null;
-		StringBuffer sb = new StringBuffer();
+		StringBuilder sb = new StringBuilder();
 		int startIndex = start;
 		int endIndex = start + length;
 		if (startIndex > oldText.length()) {
@@ -550,7 +593,7 @@ public class StringUtils {
 		int position = 0;
 		int previous = 0;
 		int spacer = source.length();
-		StringBuffer sb = new StringBuffer(normalString);
+		StringBuilder sb = new StringBuilder(normalString);
 		while (position + spacer - 1 < length && aString.indexOf(source, position) > -1) {
 			position = aString.indexOf(source, previous);
 			sb.append(normalString);
@@ -732,13 +775,13 @@ public class StringUtils {
 		if (s == null)
 			return new String[0];
 		StringTokenizer toker = new StringTokenizer(s, ","); //$NON-NLS-1$
-		List list = new ArrayList();
+		List<String> list = new ArrayList<>();
 		while (toker.hasMoreTokens()) {
 			// since we're separating the values with ',', escape ',' in the
 			// values
 			list.add(StringUtils.replace(toker.nextToken(), "&comma;", ",").trim()); //$NON-NLS-1$ //$NON-NLS-2$
 		}
-		return (String[]) list.toArray(new String[0]);
+		return list.toArray(new String[0]);
 	}
 
 	/**
