@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2020 IBM Corporation and others.
+ * Copyright (c) 2009, 2022 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
  * which accompanies this distribution, and is available at
@@ -350,7 +350,10 @@ public abstract class AbstractStructuredFoldingStrategy
 		public FoldingAnnotation(IndexedRegion region, boolean isCollapsed) {
 			super(isCollapsed);
 			
-			fIsVisible = false;
+			// assume visible until proven otherwise because it must be possible
+			// to programmatically collapse multi-line annotations that have
+			// never been painted, e.g. from "Collapse All"
+			fIsVisible = true;
 			fRegion = region;
 		}
 		
@@ -378,9 +381,9 @@ public abstract class AbstractStructuredFoldingStrategy
 		public void paint(GC gc, Canvas canvas, Rectangle rectangle) {
 			/* workaround for BUG85874 */
 			/*
-			 * only need to check annotations that are expanded because hidden
-			 * annotations should never have been given the chance to
-			 * collapse.
+			 * only need to check annotations that are expanded because
+			 * collapsed annotations by definition always only occupy one line
+			 * and would be wrongly hidden when containing multiple lines.
 			 */
 			if (!isCollapsed()) {
 				// working with rectangle, so line height
@@ -500,6 +503,8 @@ public abstract class AbstractStructuredFoldingStrategy
 			
 			int offset = structuredDocumentRegion.getStartOffset();
 			IndexedRegion indexedRegion = model.getIndexedRegion(offset);
+			if (indexedRegion == null)
+				continue;
 			indexedRegions.add(indexedRegion);
 			if (structuredDocumentRegion.getEndOffset() <= indexedRegion.getEndOffset())
 				continue;
