@@ -1,9 +1,11 @@
 /*******************************************************************************
- * Copyright (c) 2001, 2005 IBM Corporation and others.
+ * Copyright (c) 2001, 2020 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * are made available under the terms of the Eclipse Public License 2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
@@ -13,7 +15,7 @@
 
 package org.eclipse.wst.sse.ui.internal.provisional.preferences;
 
-import org.eclipse.wst.sse.ui.internal.preferences.EditorPreferenceNames;
+import org.eclipse.wst.sse.ui.preferences.AppearancePreferenceNames;
 
 /**
  * Common editor preference keys used by the Structured Text Editor.
@@ -30,6 +32,7 @@ public class CommonEditorPreferenceNames {
 	 * <p>
 	 * Value is of type <code>Boolean</code>.
 	 * </p>
+	 * @deprecated
 	 */
-	public static final String EVALUATE_TEMPORARY_PROBLEMS = EditorPreferenceNames.EVALUATE_TEMPORARY_PROBLEMS;
+	public static final String EVALUATE_TEMPORARY_PROBLEMS = AppearancePreferenceNames.EVALUATE_TEMPORARY_PROBLEMS;
 }
