@@ -1,9 +1,11 @@
 /*******************************************************************************
-  * Copyright (c) 2001, 2012 IBM Corporation and others.
+ * Copyright (c) 2001, 2018 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * are made available under the terms of the Eclipse Public License 2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
@@ -36,6 +38,7 @@ import org.eclipse.jface.text.reconciler.DirtyRegion;
 import org.eclipse.jface.text.reconciler.IReconciler;
 import org.eclipse.jface.text.reconciler.IReconcilerExtension;
 import org.eclipse.jface.text.reconciler.IReconcilingStrategy;
+import org.eclipse.jface.text.reconciler.IReconcilingStrategyExtension;
 import org.eclipse.wst.sse.ui.internal.Logger;
 
 /**
@@ -239,7 +242,7 @@ public class DirtyRegionProcessor implements IReconciler, IReconcilerExtension,
 	 */
 	private String fPartitioning;
 
-	Map fReconcilingStrategies = null;
+	Map<String, IReconcilingStrategy> fReconcilingStrategies = null;
 
 	/** for initial reconcile when document is opened */
 	private TextInputListener fTextInputListener = null;
@@ -265,7 +268,7 @@ public class DirtyRegionProcessor implements IReconciler, IReconcilerExtension,
 	public DirtyRegionProcessor() {
 		// init reconciler stuff
 		setDelay(UPDATE_DELAY);
-		fReconcilingStrategies = new HashMap();
+		fReconcilingStrategies = new HashMap<String, IReconcilingStrategy>();
 	}
 
 	/**
@@ -511,7 +514,7 @@ public class DirtyRegionProcessor implements IReconciler, IReconcilerExtension,
 	public IReconcilingStrategy getReconcilingStrategy(String partitionType) {
 		if (partitionType == null)
 			return null;
-		return (IReconcilingStrategy) fReconcilingStrategies.get(partitionType);
+		return fReconcilingStrategies.get(partitionType);
 	}
 
 	/**
@@ -715,7 +718,11 @@ public class DirtyRegionProcessor implements IReconciler, IReconcilerExtension,
 		}
 
 		fDocument = doc;
-
+		
+		for (IReconcilingStrategy strategy : fReconcilingStrategies.values()) {
+			strategy.setDocument(doc);
+		}
+		
 		if (fDocument != null) {
 			if (fDocument instanceof IDocumentExtension4) {
 				((IDocumentExtension4) fDocument).addDocumentRewriteSessionListener(fDocumentRewriteSessionListener);
@@ -725,12 +732,19 @@ public class DirtyRegionProcessor implements IReconciler, IReconcilerExtension,
 
 			setEntireDocumentDirty(doc);
 		}
+		
+		
 	}
 
 	/**
 	 * This method is called before the initial reconciling of the document. 
 	 */
 	protected void initialReconcile() {
+		for (IReconcilingStrategy strategy : fReconcilingStrategies.values()) {
+			if (strategy instanceof IReconcilingStrategyExtension) {
+				((IReconcilingStrategyExtension) strategy).initialReconcile();
+			}
+		}
 	}
 
 	/**
