@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2001, 2017 IBM Corporation and others.
+ * Copyright (c) 2001, 2024 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
@@ -845,7 +845,7 @@ public class ValidationPreferencePage extends PreferencePage implements	IWorkben
 
 	private void displayMessage(String title, String message, int iIconType) {
 		MessageBox messageBox = new MessageBox(getShell(),
-				org.eclipse.swt.SWT.OK | iIconType	| org.eclipse.swt.SWT.APPLICATION_MODAL);
+				org.eclipse.swt.SWT.OK | iIconType);
 		messageBox.setMessage(message);
 		messageBox.setText(title);
 		messageBox.open();
