@@ -1,9 +1,11 @@
 /*******************************************************************************
- * Copyright (c) 2002, 2013 IBM Corporation and others.
+ * Copyright (c) 2002, 2018 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * are made available under the terms of the Eclipse Public License 2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
@@ -176,7 +178,9 @@ public class CMDocumentLoader
 				  if (locations != null && !locations.isEmpty()) {
 					  // Use the externalSchemaLocation
 					  if (namespaceTable != null && namespaceTable.isNamespaceEncountered()) {
-						  final String location = locations.get(IExternalSchemaLocationProvider.SCHEMA_LOCATION).toString();
+						Object schemaLocation = locations.get(IExternalSchemaLocationProvider.SCHEMA_LOCATION);
+						if (schemaLocation != null) {
+						  final String location = schemaLocation.toString();
 						  if (location != null) {
 							  final String[] ids = StringUtils.asArray(location);
 							  // namespace : location pairs
@@ -189,11 +193,21 @@ public class CMDocumentLoader
 								  }
 							  }
 						  }
+						  else {
+							  Logger.log(Logger.ERROR_DEBUG, "External schema location provider did not return an external schema location for IExternalSchemaLocationProvider.SCHEMA_LOCATION: " + providers[i].getClass().getName()); //$NON-NLS-1$
+						  }
+						}
 					  }
 					  else { // noNamespace
-						  handleGrammar(uri.toString(), locations.get(IExternalSchemaLocationProvider.NO_NAMESPACE_SCHEMA_LOCATION).toString(), "XSD"); //$NON-NLS-1$
-						  externalSchemaLoaded = true;
-						  break;
+						  Object schemaLocation = locations.get(IExternalSchemaLocationProvider.NO_NAMESPACE_SCHEMA_LOCATION);
+						  if (schemaLocation != null) {
+						    handleGrammar(uri.toString(), schemaLocation.toString(), "XSD"); //$NON-NLS-1$
+						    externalSchemaLoaded = true;
+						    break;
+						  }
+						  else {
+						    Logger.log(Logger.ERROR_DEBUG, "External schema location provider did not return an external schema location for IExternalSchemaLocationProvider.NO_NAMESPACE_SCHEMA_LOCATION: " + providers[i].getClass().getName()); //$NON-NLS-1$
+						  }
 					  }
 				  }
 			  }
@@ -322,7 +336,7 @@ public class CMDocumentLoader
   static IPath getInternalSubsetPath(Document document) {
 	  IPath path = Path.EMPTY;
 	  if (document instanceof IAdaptable) {
-			final IResource resource = (IResource) ((IAdaptable) document).getAdapter(IResource.class);
+			final IResource resource = ((IAdaptable) document).getAdapter(IResource.class);
 			if (resource instanceof IFile) {
 				CRC32 calc = new CRC32();
 				calc.update(resource.getFullPath().toString().getBytes());
