@@ -47,6 +47,7 @@ import org.apache.xerces.xni.XNIException;
 import org.apache.xerces.xni.parser.XMLEntityResolver;
 import org.apache.xerces.xni.parser.XMLInputSource;
 import org.eclipse.core.resources.IFile;
+import org.eclipse.core.resources.IMarker;
 import org.eclipse.core.resources.IResource;
 import org.eclipse.core.resources.IWorkspace;
 import org.eclipse.core.resources.ResourcesPlugin;
@@ -372,14 +373,17 @@ public class XMLValidator
     	}finally{
     		Thread.currentThread().setContextClassLoader(originalClzLoader);
     	}
-           
-        if(configuration.getIntFeature(XMLValidationConfiguration.INDICATE_NO_GRAMMAR) > 0 && 
+
+        // 0 accounts for it not being set at all
+        if(configuration.getIntFeature(XMLValidationConfiguration.INDICATE_NO_GRAMMAR) > 0 &&
         		valinfo.isValid() && !isGrammarEncountered)
         {
-          if(configuration.getIntFeature(XMLValidationConfiguration.INDICATE_NO_GRAMMAR) == 1)
+          if(configuration.getIntFeature(XMLValidationConfiguration.INDICATE_NO_GRAMMAR) == IMarker.SEVERITY_WARNING)
             valinfo.addWarning(XMLValidationMessages._WARN_NO_GRAMMAR, 1, 0, uri, NO_GRAMMAR_FOUND, null);
-          else // 2
+          else if (configuration.getIntFeature(XMLValidationConfiguration.INDICATE_NO_GRAMMAR) == IMarker.SEVERITY_ERROR) // 2
               valinfo.addError(XMLValidationMessages._WARN_NO_GRAMMAR, 1, 0, uri, NO_GRAMMAR_FOUND, null);
+          else
+              valinfo.addInfo(XMLValidationMessages._WARN_NO_GRAMMAR, 1, 0, uri, NO_GRAMMAR_FOUND, null);
         }
         if(configuration.getIntFeature(XMLValidationConfiguration.INDICATE_NO_DOCUMENT_ELEMENT) > 0 && valinfo.isValid() && !helper.isDocumentElementEncountered) {
         	if(configuration.getIntFeature(XMLValidationConfiguration.INDICATE_NO_DOCUMENT_ELEMENT) == 1)
@@ -864,7 +868,8 @@ public class XMLValidator
             /* (non-Javadoc)
              * @see org.apache.xerces.impl.XMLErrorReporter#reportError(java.lang.String, java.lang.String, java.lang.Object[], short)
              */
-            public void reportError(String domain, String key, Object[] arguments, short severity) throws XNIException
+    		@Override
+            public String reportError(String domain, String key, Object[] arguments, short severity) throws XNIException
             {
 		      boolean reportError = true;
               valinfo.setCurrentErrorKey(key);  
@@ -899,8 +904,13 @@ public class XMLValidator
               }          
 		      if (reportError)
 		      {
-		        super.reportError(domain, key, arguments, severity);
+		        String formattedError = super.reportError(domain, key, arguments, severity);
 		        valinfo.getErrorCustomizationManager().considerReportedError(valinfo, key, arguments);
+		        return formattedError;
+		      }
+		      else
+		      {
+		    	return null;
 		      }
 		    }
 		};
