@@ -1,9 +1,11 @@
 /*******************************************************************************
- * Copyright (c) 2001, 2011 IBM Corporation and others.
+ * Copyright (c) 2001, 2018 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * are made available under the terms of the Eclipse Public License 2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
@@ -523,6 +525,9 @@ public class DOMModelImpl extends AbstractStructuredModel implements IStructured
 			this.refresh = false;
 			parser.replaceStructuredDocumentRegions(getStructuredDocument().getRegionList(), null);
 		}
+		catch (DOMException dex) {
+			// this resulted from a text change, do not log it
+		}
 		catch (Exception ex) {
 			Logger.logException(ex);
 		}
@@ -736,6 +741,11 @@ public class DOMModelImpl extends AbstractStructuredModel implements IStructured
 		try {
 			parser.replaceStructuredDocumentRegions(newStructuredDocumentRegions, oldStructuredDocumentRegions);
 		}
+		catch (DOMException dex) {
+			// this resulted from a text change, do not log it
+			this.refresh = true;
+			handleRefresh();
+		}
 		catch (Exception ex) {
 			Logger.logException(ex);
 			this.refresh = true;
