@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2010, 2020 IBM Corporation and others.
+ * Copyright (c) 2010, 2021 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
  * which accompanies this distribution, and is available at
@@ -592,7 +592,7 @@ public abstract class AbstractXMLModelQueryCompletionProposalComputer extends Ab
 				// |
 				if (needsEndTag(xmlEndTagOpen, context)) {
 					String tagName = getTagName(xmlEndTagOpen);
-					xmlEndTagOpen.getTextEndOffset();
+					replaceBegin = xmlEndTagOpen.getTextEndOffset();
 					replaceLength = 0;
 					replaceText = "</" + tagName + ">"; //$NON-NLS-1$ //$NON-NLS-2$ $NON-NLS-2$
 					cursorOffset = tagName.length() + 3;
